#!/usr/bin/bash
genliveinitrd=0

getopt -T >/dev/null
if [ $? -ne 4 ]; then
    echo "getopt -T failed"
    exit 1
fi
PARSED=$(getopt -o l -l live -n "$0" -- "$@")
[ ! $? ] && exit 2
eval set -- "$PARSED"
while true; do
    case $1 in
        -l|--live)
            genliveinitrd=1
            shift
            ;;
        --)
            shift
            break
            ;;
    esac
done

function set_cfg()
{
    file="$1"
    var="$2"
    val="$3"
    d="${4:-=}"
    if grep -q "^$var$d" "$file"; then
        sed -i "s|^$var$d.*$|$var$d$val|" "$file"
    else
        echo "$var$d$val" >> "$file"
    fi
}

dnf config-manager --add-repo=https://repo.jmich.net/fedora/jmich.repo

dnf -y install kernel-*gpdpocket tlp gpd-fan
systemctl enable gpd-fan

if [ $genliveinitrd -eq 1 ]; then
    dnf -y install dracut-live
    kernelver=$(find /boot -name "vmlinuz-*gpdpocket" | sed 's|.*/vmlinuz-||')
    dracut initramfs-$kernelver.img $kernelver --nomdadmconf --nolvmconf --xz \
        --add 'livenet dmsquash-live convertfs pollcdrom qemu qemu-net' \
        --omit 'plymouth' --no-hostonly --no-early-microcode --force
fi

#power
set_cfg /etc/default/tlp DISK_DEVICES '"mmcblk0"'
set_cfg /etc/default/tlp DISK_IOSCHED '"deadline"'

#wifi
cp -f wifi/brcmfmac4356-pcie.txt /lib/firmware/brcm/

#bluetooth
echo "btusb" > /etc/modules-load.d/btusb.conf

#xorg
cp -f xorg/*.conf /etc/X11/xorg.conf.d/
set_cfg /etc/gdm/custom.conf WaylandEnable false
mkdir -p /var/lib/gdm/.config &> /dev/null
cp -f xorg/monitors.xml /var/lib/gdm/.config/
mkdir -p /etc/skel/.config
cp -f xorg/monitors.xml /etc/skel/.config/
for d in /home/*; do
    if [ "${d##*/}" != "lost+found" ]; then
        mkdir -p "$d/.config"
        cp -f xorg/monitors.xml "$d/.config/"
    fi
done

#udev
#touchscreen rotation, it is not necessary in f27
#cp -f udev/99-touchscreen.rules /etc/udev/rules.d/

#audio
cp -f audio/HiFi.conf /usr/share/alsa/ucm/chtrt5645/
set_cfg /etc/pulse/default.pa set-card-profile 'alsa_card.platform-cht-bsw-rt5645 HiFi' ' '
set_cfg /etc/pulse/default.pa set-default-sink 'alsa_output.platform-cht-bsw-rt5645.HiFi__hw_chtrt5645__sink' ' '
set_cfg /etc/pulse/default.pa set-sink-port 'alsa_output.platform-cht-bsw-rt5645.HiFi__hw_chtrt5645__sink [Out] Speaker' ' '
set_cfg /etc/pulse/daemon.conf realtime-scheduling no

#clean cache so it's not saved to LiveOS image
if [ $genliveinitrd -eq 1 ]; then
    dnf clean all
fi
